<?php

namespace Drupal\layout_builder_kit\Entity;

use Drupal\Core\Entity\ContentEntityInterface;
use Drupal\Core\Entity\RevisionLogInterface;
use Drupal\Core\Entity\EntityChangedInterface;
use Drupal\user\EntityOwnerInterface;

/**
 * Provides an interface for defining LBKIcon entities.
 *
 * @ingroup layout_builder_kit
 */
interface LBKIconInterface extends ContentEntityInterface, RevisionLogInterface, EntityChangedInterface, EntityOwnerInterface {

  // Add get/set methods for your configuration properties here.

  /**
   * Gets the LBKIcon name.
   *
   * @return string
   *   Name of the LBKIcon.
   */
  public function getName();

  /**
   * Sets the LBKIcon name.
   *
   * @param string $name
   *   The LBKIcon name.
   *
   * @return \Drupal\layout_builder_kit\Entity\LBKIconInterface
   *   The called LBKIcon entity.
   */
  public function setName($name);

  /**
   * Gets the LBKIcon creation timestamp.
   *
   * @return int
   *   Creation timestamp of the LBKIcon.
   */
  public function getCreatedTime();

  /**
   * Sets the LBKIcon creation timestamp.
   *
   * @param int $timestamp
   *   The LBKIcon creation timestamp.
   *
   * @return \Drupal\layout_builder_kit\Entity\LBKIconInterface
   *   The called LBKIcon entity.
   */
  public function setCreatedTime($timestamp);

  /**
   * Returns the LBKIcon published status indicator.
   *
   * Unpublished LBKIcon are only visible to restricted users.
   *
   * @return bool
   *   TRUE if the LBKIcon is published.
   */
  public function isPublished();

  /**
   * Sets the published status of a LBKIcon.
   *
   * @param bool $published
   *   TRUE to set this LBKIcon to published, FALSE to set it to unpublished.
   *
   * @return \Drupal\layout_builder_kit\Entity\LBKIconInterface
   *   The called LBKIcon entity.
   */
  public function setPublished($published);

  /**
   * Gets the LBKIcon revision creation timestamp.
   *
   * @return int
   *   The UNIX timestamp of when this revision was created.
   */
  public function getRevisionCreationTime();

  /**
   * Sets the LBKIcon revision creation timestamp.
   *
   * @param int $timestamp
   *   The UNIX timestamp of when this revision was created.
   *
   * @return \Drupal\layout_builder_kit\Entity\LBKIconInterface
   *   The called LBKIcon entity.
   */
  public function setRevisionCreationTime($timestamp);

  /**
   * Gets the LBKIcon revision author.
   *
   * @return \Drupal\user\UserInterface
   *   The user entity for the revision author.
   */
  public function getRevisionUser();

  /**
   * Sets the LBKIcon revision author.
   *
   * @param int $uid
   *   The user ID of the revision author.
   *
   * @return \Drupal\layout_builder_kit\Entity\LBKIconInterface
   *   The called LBKIcon entity.
   */
  public function setRevisionUserId($uid);

}
