<?php

namespace Drupal\layout_builder_kit\Entity;

use Drupal\Core\Entity\EntityStorageInterface;
use Drupal\Core\Field\BaseFieldDefinition;
use Drupal\Core\Entity\RevisionableContentEntityBase;
use Drupal\Core\Entity\RevisionableInterface;
use Drupal\Core\Entity\EntityChangedTrait;
use Drupal\Core\Entity\EntityTypeInterface;
use Drupal\user\UserInterface;

/**
 * Defines the LBKImage Entity entity.
 *
 * @ingroup layout_builder_kit
 *
 * @ContentEntityType(
 *   id = "lbk_image_entity",
 *   label = @Translation("LBKImage Entity"),
 *   bundle_label = @Translation("LBKImage Entity type"),
 *   handlers = {
 *     "storage" = "Drupal\layout_builder_kit\LBKImageEntityStorage",
 *     "view_builder" = "Drupal\Core\Entity\EntityViewBuilder",
 *     "list_builder" = "Drupal\layout_builder_kit\LBKImageEntityListBuilder",
 *     "views_data" = "Drupal\layout_builder_kit\Entity\LBKImageEntityViewsData",
 *     "translation" = "Drupal\layout_builder_kit\LBKImageEntityTranslationHandler",
 *
 *     "form" = {
 *       "default" = "Drupal\layout_builder_kit\Form\LBKImageEntityForm",
 *       "add" = "Drupal\layout_builder_kit\Form\LBKImageEntityForm",
 *       "edit" = "Drupal\layout_builder_kit\Form\LBKImageEntityForm",
 *       "delete" = "Drupal\layout_builder_kit\Form\LBKImageEntityDeleteForm",
 *     },
 *     "access" = "Drupal\layout_builder_kit\LBKImageEntityAccessControlHandler",
 *     "route_provider" = {
 *       "html" = "Drupal\layout_builder_kit\LBKImageEntityHtmlRouteProvider",
 *     },
 *   },
 *   base_table = "lbk_image_entity",
 *   data_table = "lbk_image_entity_field_data",
 *   revision_table = "lbk_image_entity_revision",
 *   revision_data_table = "lbk_image_entity_field_revision",
 *   translatable = TRUE,
 *   admin_permission = "administer lbkimage entity entities",
 *   entity_keys = {
 *     "id" = "id",
 *     "revision" = "vid",
 *     "bundle" = "type",
 *     "label" = "name",
 *     "uuid" = "uuid",
 *     "uid" = "user_id",
 *     "langcode" = "langcode",
 *     "status" = "status",
 *   },
 *   links = {
 *     "canonical" = "/admin/structure/lbk_image_entity/{lbk_image_entity}",
 *     "add-page" = "/admin/structure/lbk_image_entity/add",
 *     "add-form" = "/admin/structure/lbk_image_entity/add/{lbk_image_entity_type}",
 *     "edit-form" = "/admin/structure/lbk_image_entity/{lbk_image_entity}/edit",
 *     "delete-form" = "/admin/structure/lbk_image_entity/{lbk_image_entity}/delete",
 *     "version-history" = "/admin/structure/lbk_image_entity/{lbk_image_entity}/revisions",
 *     "revision" = "/admin/structure/lbk_image_entity/{lbk_image_entity}/revisions/{lbk_image_entity_revision}/view",
 *     "revision_revert" = "/admin/structure/lbk_image_entity/{lbk_image_entity}/revisions/{lbk_image_entity_revision}/revert",
 *     "revision_delete" = "/admin/structure/lbk_image_entity/{lbk_image_entity}/revisions/{lbk_image_entity_revision}/delete",
 *     "translation_revert" = "/admin/structure/lbk_image_entity/{lbk_image_entity}/revisions/{lbk_image_entity_revision}/revert/{langcode}",
 *     "collection" = "/admin/structure/lbk_image_entity",
 *   },
 *   bundle_entity_type = "lbk_image_entity_type",
 *   field_ui_base_route = "entity.lbk_image_entity_type.edit_form"
 * )
 */
class LBKImageEntity extends RevisionableContentEntityBase implements LBKImageEntityInterface {

  use EntityChangedTrait;

  /**
   * {@inheritdoc}
   */
  public static function preCreate(EntityStorageInterface $storage_controller, array &$values) {
    parent::preCreate($storage_controller, $values);
    $values += [
      'user_id' => \Drupal::currentUser()->id(),
    ];
  }

  /**
   * {@inheritdoc}
   */
  protected function urlRouteParameters($rel) {
    $uri_route_parameters = parent::urlRouteParameters($rel);

    if ($rel === 'revision_revert' && $this instanceof RevisionableInterface) {
      $uri_route_parameters[$this->getEntityTypeId() . '_revision'] = $this->getRevisionId();
    }
    elseif ($rel === 'revision_delete' && $this instanceof RevisionableInterface) {
      $uri_route_parameters[$this->getEntityTypeId() . '_revision'] = $this->getRevisionId();
    }

    return $uri_route_parameters;
  }

  /**
   * {@inheritdoc}
   */
  public function preSave(EntityStorageInterface $storage) {
    parent::preSave($storage);

    foreach (array_keys($this->getTranslationLanguages()) as $langcode) {
      $translation = $this->getTranslation($langcode);

      // If no owner has been set explicitly, make the anonymous user the owner.
      if (!$translation->getOwner()) {
        $translation->setOwnerId(0);
      }
    }

    // If no revision author has been set explicitly, make the lbk_image_entity owner the
    // revision author.
    if (!$this->getRevisionUser()) {
      $this->setRevisionUserId($this->getOwnerId());
    }
  }

  /**
   * {@inheritdoc}
   */
  public function getName() {
    return $this->get('name')->value;
  }

  /**
   * {@inheritdoc}
   */
  public function setName($name) {
    $this->set('name', $name);
    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public function getCreatedTime() {
    return $this->get('created')->value;
  }

  /**
   * {@inheritdoc}
   */
  public function setCreatedTime($timestamp) {
    $this->set('created', $timestamp);
    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public function getOwner() {
    return $this->get('user_id')->entity;
  }

  /**
   * {@inheritdoc}
   */
  public function getOwnerId() {
    return $this->get('user_id')->target_id;
  }

  /**
   * {@inheritdoc}
   */
  public function setOwnerId($uid) {
    $this->set('user_id', $uid);
    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public function setOwner(UserInterface $account) {
    $this->set('user_id', $account->id());
    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public function isPublished() {
    return (bool) $this->getEntityKey('status');
  }

  /**
   * {@inheritdoc}
   */
  public function setPublished($published) {
    $this->set('status', $published ? TRUE : FALSE);
    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public static function baseFieldDefinitions(EntityTypeInterface $entity_type) {
    $fields = parent::baseFieldDefinitions($entity_type);

    $fields['user_id'] = BaseFieldDefinition::create('entity_reference')
      ->setLabel(t('Authored by'))
      ->setDescription(t('The user ID of author of the LBKImage Entity entity.'))
      ->setRevisionable(TRUE)
      ->setSetting('target_type', 'user')
      ->setSetting('handler', 'default')
      ->setTranslatable(TRUE)
      ->setDisplayOptions('view', [
        'label' => 'hidden',
        'type' => 'author',
        'weight' => 0,
      ])
      ->setDisplayOptions('form', [
        'type' => 'entity_reference_autocomplete',
        'weight' => 5,
        'settings' => [
          'match_operator' => 'CONTAINS',
          'size' => '60',
          'autocomplete_type' => 'tags',
          'placeholder' => '',
        ],
      ])
      ->setDisplayConfigurable('form', TRUE)
      ->setDisplayConfigurable('view', TRUE);

    $fields['name'] = BaseFieldDefinition::create('string')
      ->setLabel(t('Name'))
      ->setDescription(t('The name of the Kit entity.'))
      ->setRevisionable(TRUE)
      ->setSettings([
        'max_length' => 50,
        'text_processing' => 0,
      ])
      ->setDefaultValue('')
      ->setDisplayOptions('view', [
        'label' => 'above',
        'type' => 'string',
        'weight' => -4,
      ])
      ->setDisplayOptions('form', [
        'type' => 'string_textfield',
        'weight' => -4,
      ])
      ->setDisplayConfigurable('form', TRUE)
      ->setDisplayConfigurable('view', TRUE)
      ->setRequired(TRUE);

    $fields['display_title'] = BaseFieldDefinition::create('boolean')
      ->setLabel(t('Display title'))
      ->setRevisionable(TRUE)
      ->setDisplayOptions('view', [
        'label' => 'above',
        'weight' => 7,
      ])
      ->setDisplayOptions('form', [
        'type' => 'boolean_checkbox',
        'settings' => [
          'display_label' => TRUE,
        ],
        'weight' => 7,
      ])
      ->setDisplayConfigurable('form', TRUE)
      ->setDisplayConfigurable('view', TRUE);

    $fields['block_id'] = BaseFieldDefinition::create('string')
      ->setLabel(t('Block ID'))
      ->setDescription(t('The Block ID.'))
      ->setRevisionable(TRUE)
      ->setSettings([
        'max_length' => 50,
        'text_processing' => 0,
      ])
      ->setDefaultValue('')
      ->setDisplayOptions('view', [
        'label' => 'above',
        'type' => 'string',
        'weight' => -4,
      ])
      ->setDisplayOptions('form', [
        'type' => 'string_textfield',
        'weight' => -4,
      ])
      ->setDisplayConfigurable('form', TRUE)
      ->setDisplayConfigurable('view', TRUE)
      ->setRequired(TRUE);

    $fields['image_id'] = BaseFieldDefinition::create('string')
      ->setLabel(t('Image ID'))
      ->setDescription(t('The Image ID.'))
      ->setRevisionable(TRUE)
      ->setSettings([
        'max_length' => 50,
        'text_processing' => 0,
      ])
      ->setDefaultValue('')
      ->setDisplayOptions('view', [
        'label' => 'above',
        'type' => 'string',
        'weight' => -4,
      ])
      ->setDisplayOptions('form', [
        'type' => 'string_textfield',
        'weight' => -4,
      ])
      ->setDisplayConfigurable('form', TRUE)
      ->setDisplayConfigurable('view', TRUE)
      ->setRequired(TRUE);

    $fields['css_class'] = BaseFieldDefinition::create('string')
      ->setLabel(t('CSS Class'))
      ->setDescription('')
      ->setSettings([
        'max_length' => 120,
        'text_processing' => 0,
      ])
      ->setDefaultValue('')
      ->setDisplayOptions('view', [
        'label' => 'above',
        'weight' => -1,
      ])
      ->setDisplayOptions('form', [
        'settings' => [
          'placeholder' => '',
        ],
        'weight' => -1,
      ])
      ->setDisplayConfigurable('form', TRUE)
      ->setDisplayConfigurable('view', TRUE);

    $fields['title_alignment'] = BaseFieldDefinition::create('list_string')
      ->setLabel(t('Title Alignment'))
      ->setDescription('')
      ->setRequired(TRUE)
      ->setSettings([
        'max_length' => 60,
        'text_processing' => 0,
        'allowed_values' => [
          'title_on_top' => t('Top'),
          'title_on_bottom' => t('Bottom'),
        ],
      ])
      ->setDefaultValue('')
      ->setDisplayOptions('view', [
        'label' => 'above',
        'weight' => -20,
      ])
      ->setDisplayOptions('form', [
        'type' => 'options_select',
        'weight' => -20,
      ])
      ->setDisplayConfigurable('form', TRUE)
      ->setDisplayConfigurable('view', TRUE);

    $fields['image_style'] = BaseFieldDefinition::create('list_string')
      ->setLabel(t('Image Style'))
      ->setDescription('')
      ->setRequired(TRUE)
      ->setSettings([
        'max_length' => 60,
        'text_processing' => 0,
        'allowed_values' => [
          'none' => t('None'),
          'thumbnail' => t('Thumbnail'),
          'medium' => t('Medium'),
          'large' => t('Large'),
        ],
      ])
      ->setDefaultValue('')
      ->setDisplayOptions('view', [
        'label' => 'above',
        'weight' => -20,
      ])
      ->setDisplayOptions('form', [
        'type' => 'options_select',
        'weight' => -20,
      ])
      ->setDisplayConfigurable('form', TRUE)
      ->setDisplayConfigurable('view', TRUE);

    $fields['alignment'] = BaseFieldDefinition::create('list_string')
      ->setLabel(t('Alignment'))
      ->setDescription('')
      ->setRequired(TRUE)
      ->setSettings([
        'max_length' => 60,
        'text_processing' => 0,
        'allowed_values' => [
          'left' => t('Left'),
          'center' => t('Center'),
          'right' => t('Right'),
        ],
      ])
      ->setDefaultValue('')
      ->setDisplayOptions('view', [
        'label' => 'above',
        'weight' => -20,
      ])
      ->setDisplayOptions('form', [
        'type' => 'options_select',
        'weight' => -20,
      ])
      ->setDisplayConfigurable('form', TRUE)
      ->setDisplayConfigurable('view', TRUE);

    $fields['overlay_text'] = BaseFieldDefinition::create('text_long')
      ->setLabel(t('Overlay Text'))
      ->setDescription('')
      ->setSettings([
        'default_value' => '',
        'text_processing' => 0,
      ])
      ->setDisplayOptions('form', [
        'type' => 'text_textfield',
        'weight' => 3,
        'settings' => [
          'rows' => 4,
        ],
      ])
      ->setDisplayOptions('view', [
        'type' => 'text_default',
        'weight' => 3,
      ])
      ->setDisplayConfigurable('form', TRUE)
      ->setDisplayConfigurable('view', TRUE);

    $fields['overlay_text_position'] = BaseFieldDefinition::create('list_string')
      ->setLabel(t('Overlay Text Position'))
      ->setDescription('')
      ->setRequired(TRUE)
      ->setSettings([
        'max_length' => 60,
        'text_processing' => 0,
        'allowed_values' => [
          'none' => t('None'),
          'bottom' => t('Bottom'),
        ],
      ])
      ->setDefaultValue('')
      ->setDisplayOptions('view', [
        'label' => 'above',
        'weight' => -20,
      ])
      ->setDisplayOptions('form', [
        'type' => 'options_select',
        'weight' => -20,
      ])
      ->setDisplayConfigurable('form', TRUE)
      ->setDisplayConfigurable('view', TRUE);

    $fields['status'] = BaseFieldDefinition::create('boolean')
      ->setLabel(t('Publishing status'))
      ->setDescription(t('A boolean indicating whether the LBKImage Entity is published.'))
      ->setRevisionable(TRUE)
      ->setDefaultValue(TRUE)
      ->setDisplayOptions('form', [
        'type' => 'boolean_checkbox',
        'weight' => -3,
      ]);

    $fields['created'] = BaseFieldDefinition::create('created')
      ->setLabel(t('Created'))
      ->setDescription(t('The time that the entity was created.'));

    $fields['changed'] = BaseFieldDefinition::create('changed')
      ->setLabel(t('Changed'))
      ->setDescription(t('The time that the entity was last edited.'));

    $fields['revision_translation_affected'] = BaseFieldDefinition::create('boolean')
      ->setLabel(t('Revision translation affected'))
      ->setDescription(t('Indicates if the last edit of a translation belongs to current revision.'))
      ->setReadOnly(TRUE)
      ->setRevisionable(TRUE)
      ->setTranslatable(TRUE);

    return $fields;
  }

}
