<?php

namespace Drupal\layout_builder_kit\Entity;

use Drupal\Core\Entity\ContentEntityInterface;
use Drupal\Core\Entity\RevisionLogInterface;
use Drupal\Core\Entity\EntityChangedInterface;
use Drupal\user\EntityOwnerInterface;

/**
 * Provides an interface for defining LBKImage Entity entities.
 *
 * @ingroup layout_builder_kit
 */
interface LBKImageEntityInterface extends ContentEntityInterface, RevisionLogInterface, EntityChangedInterface, EntityOwnerInterface {

  // Add get/set methods for your configuration properties here.

  /**
   * Gets the LBKImage Entity name.
   *
   * @return string
   *   Name of the LBKImage Entity.
   */
  public function getName();

  /**
   * Sets the LBKImage Entity name.
   *
   * @param string $name
   *   The LBKImage Entity name.
   *
   * @return \Drupal\layout_builder_kit\Entity\LBKImageEntityInterface
   *   The called LBKImage Entity entity.
   */
  public function setName($name);

  /**
   * Gets the LBKImage Entity creation timestamp.
   *
   * @return int
   *   Creation timestamp of the LBKImage Entity.
   */
  public function getCreatedTime();

  /**
   * Sets the LBKImage Entity creation timestamp.
   *
   * @param int $timestamp
   *   The LBKImage Entity creation timestamp.
   *
   * @return \Drupal\layout_builder_kit\Entity\LBKImageEntityInterface
   *   The called LBKImage Entity entity.
   */
  public function setCreatedTime($timestamp);

  /**
   * Returns the LBKImage Entity published status indicator.
   *
   * Unpublished LBKImage Entity are only visible to restricted users.
   *
   * @return bool
   *   TRUE if the LBKImage Entity is published.
   */
  public function isPublished();

  /**
   * Sets the published status of a LBKImage Entity.
   *
   * @param bool $published
   *   TRUE to set this LBKImage Entity to published, FALSE to set it to unpublished.
   *
   * @return \Drupal\layout_builder_kit\Entity\LBKImageEntityInterface
   *   The called LBKImage Entity entity.
   */
  public function setPublished($published);

  /**
   * Gets the LBKImage Entity revision creation timestamp.
   *
   * @return int
   *   The UNIX timestamp of when this revision was created.
   */
  public function getRevisionCreationTime();

  /**
   * Sets the LBKImage Entity revision creation timestamp.
   *
   * @param int $timestamp
   *   The UNIX timestamp of when this revision was created.
   *
   * @return \Drupal\layout_builder_kit\Entity\LBKImageEntityInterface
   *   The called LBKImage Entity entity.
   */
  public function setRevisionCreationTime($timestamp);

  /**
   * Gets the LBKImage Entity revision author.
   *
   * @return \Drupal\user\UserInterface
   *   The user entity for the revision author.
   */
  public function getRevisionUser();

  /**
   * Sets the LBKImage Entity revision author.
   *
   * @param int $uid
   *   The user ID of the revision author.
   *
   * @return \Drupal\layout_builder_kit\Entity\LBKImageEntityInterface
   *   The called LBKImage Entity entity.
   */
  public function setRevisionUserId($uid);

}
