<?php

namespace Drupal\layout_builder_kit;

use Drupal\Core\Entity\Sql\SqlContentEntityStorage;
use Drupal\Core\Session\AccountInterface;
use Drupal\Core\Language\LanguageInterface;
use Drupal\layout_builder_kit\Entity\LBKIconInterface;

/**
 * Defines the storage handler class for LBKIcon entities.
 *
 * This extends the base storage class, adding required special handling for
 * LBKIcon entities.
 *
 * @ingroup layout_builder_kit
 */
class LBKIconStorage extends SqlContentEntityStorage implements LBKIconStorageInterface {

  /**
   * {@inheritdoc}
   */
  public function revisionIds(LBKIconInterface $entity) {
    return $this->database->query(
      'SELECT vid FROM {lbk_icon_revision} WHERE id=:id ORDER BY vid',
      [':id' => $entity->id()]
    )->fetchCol();
  }

  /**
   * {@inheritdoc}
   */
  public function userRevisionIds(AccountInterface $account) {
    return $this->database->query(
      'SELECT vid FROM {lbk_icon_field_revision} WHERE uid = :uid ORDER BY vid',
      [':uid' => $account->id()]
    )->fetchCol();
  }

  /**
   * {@inheritdoc}
   */
  public function countDefaultLanguageRevisions(LBKIconInterface $entity) {
    return $this->database->query('SELECT COUNT(*) FROM {lbk_icon_field_revision} WHERE id = :id AND default_langcode = 1', [':id' => $entity->id()])
      ->fetchField();
  }

  /**
   * {@inheritdoc}
   */
  public function clearRevisionsLanguage(LanguageInterface $language) {
    return $this->database->update('lbk_icon_revision')
      ->fields(['langcode' => LanguageInterface::LANGCODE_NOT_SPECIFIED])
      ->condition('langcode', $language->getId())
      ->execute();
  }

}
