<?php

namespace Drupal\layout_builder_kit;

use Drupal\Core\Entity\ContentEntityStorageInterface;
use Drupal\Core\Session\AccountInterface;
use Drupal\Core\Language\LanguageInterface;
use Drupal\layout_builder_kit\Entity\LBKIconInterface;

/**
 * Defines the storage handler class for LBKIcon entities.
 *
 * This extends the base storage class, adding required special handling for
 * LBKIcon entities.
 *
 * @ingroup layout_builder_kit
 */
interface LBKIconStorageInterface extends ContentEntityStorageInterface {

  /**
   * Gets a list of LBKIcon revision IDs for a specific LBKIcon.
   *
   * @param \Drupal\layout_builder_kit\Entity\LBKIconInterface $entity
   *   The LBKIcon entity.
   *
   * @return int[]
   *   LBKIcon revision IDs (in ascending order).
   */
  public function revisionIds(LBKIconInterface $entity);

  /**
   * Gets a list of revision IDs having a given user as LBKIcon author.
   *
   * @param \Drupal\Core\Session\AccountInterface $account
   *   The user entity.
   *
   * @return int[]
   *   LBKIcon revision IDs (in ascending order).
   */
  public function userRevisionIds(AccountInterface $account);

  /**
   * Counts the number of revisions in the default language.
   *
   * @param \Drupal\layout_builder_kit\Entity\LBKIconInterface $entity
   *   The LBKIcon entity.
   *
   * @return int
   *   The number of revisions in the default language.
   */
  public function countDefaultLanguageRevisions(LBKIconInterface $entity);

  /**
   * Unsets the language for all LBKIcon with the given language.
   *
   * @param \Drupal\Core\Language\LanguageInterface $language
   *   The language object.
   */
  public function clearRevisionsLanguage(LanguageInterface $language);

}
