<?php

namespace Drupal\layout_builder_kit;

use Drupal\Core\Entity\EntityAccessControlHandler;
use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Session\AccountInterface;
use Drupal\Core\Access\AccessResult;

/**
 * Access controller for the LBKImage Entity entity.
 *
 * @see \Drupal\layout_builder_kit\Entity\LBKImageEntity.
 */
class LBKImageEntityAccessControlHandler extends EntityAccessControlHandler {

  /**
   * {@inheritdoc}
   */
  protected function checkAccess(EntityInterface $entity, $operation, AccountInterface $account) {
    /** @var \Drupal\layout_builder_kit\Entity\LBKImageEntityInterface $entity */
    switch ($operation) {
      case 'view':
        if (!$entity->isPublished()) {
          return AccessResult::allowedIfHasPermission($account, 'view unpublished lbkimage entity entities');
        }
        return AccessResult::allowedIfHasPermission($account, 'view published lbkimage entity entities');

      case 'update':
        return AccessResult::allowedIfHasPermission($account, 'edit lbkimage entity entities');

      case 'delete':
        return AccessResult::allowedIfHasPermission($account, 'delete lbkimage entity entities');
    }

    // Unknown operation, no opinion.
    return AccessResult::neutral();
  }

  /**
   * {@inheritdoc}
   */
  protected function checkCreateAccess(AccountInterface $account, array $context, $entity_bundle = NULL) {
    return AccessResult::allowedIfHasPermission($account, 'add lbkimage entity entities');
  }

}
