<?php

namespace Drupal\layout_builder_kit;

use Drupal\Core\Entity\ContentEntityStorageInterface;
use Drupal\Core\Session\AccountInterface;
use Drupal\Core\Language\LanguageInterface;
use Drupal\layout_builder_kit\Entity\LBKImageEntityInterface;

/**
 * Defines the storage handler class for LBKImage Entity entities.
 *
 * This extends the base storage class, adding required special handling for
 * LBKImage Entity entities.
 *
 * @ingroup layout_builder_kit
 */
interface LBKImageEntityStorageInterface extends ContentEntityStorageInterface {

  /**
   * Gets a list of LBKImage Entity revision IDs for a specific LBKImage Entity.
   *
   * @param \Drupal\layout_builder_kit\Entity\LBKImageEntityInterface $entity
   *   The LBKImage Entity entity.
   *
   * @return int[]
   *   LBKImage Entity revision IDs (in ascending order).
   */
  public function revisionIds(LBKImageEntityInterface $entity);

  /**
   * Gets a list of revision IDs having a given user as LBKImage Entity author.
   *
   * @param \Drupal\Core\Session\AccountInterface $account
   *   The user entity.
   *
   * @return int[]
   *   LBKImage Entity revision IDs (in ascending order).
   */
  public function userRevisionIds(AccountInterface $account);

  /**
   * Counts the number of revisions in the default language.
   *
   * @param \Drupal\layout_builder_kit\Entity\LBKImageEntityInterface $entity
   *   The LBKImage Entity entity.
   *
   * @return int
   *   The number of revisions in the default language.
   */
  public function countDefaultLanguageRevisions(LBKImageEntityInterface $entity);

  /**
   * Unsets the language for all LBKImage Entity with the given language.
   *
   * @param \Drupal\Core\Language\LanguageInterface $language
   *   The language object.
   */
  public function clearRevisionsLanguage(LanguageInterface $language);

}
