<?php

namespace Drupal\layout_builder_kit\Plugin\Block\LBKRichText;

use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\layout_builder_kit\Plugin\Block\LBKBaseComponent;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides a 'LBKRichText' block.
 *
 * @Block(
 *  id = "lbk_rich_text",
 *  admin_label = @Translation("Rich Text (LBK)"),
 * )
 */
class LBKRichText extends LBKBaseComponent implements ContainerFactoryPluginInterface {

  /**
   * Drupal\Core\Entity\EntityTypeManagerInterface definition.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * Constructs a new GridComponent object.
   *
   * @param array $configuration
   *   A configuration array containing information about the plugin instance.
   * @param string $pluginId
   *   The plugin_id for the plugin instance.
   * @param string $pluginDefinition
   *   The plugin implementation definition.
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entityTypeManager
   *   The EntityTypeManagerInterface service.
   */
  public function __construct(
    array $configuration,
    $pluginId,
    $pluginDefinition,
    EntityTypeManagerInterface $entityTypeManager
  ) {
    parent::__construct($configuration, $pluginId, $pluginDefinition);
    $this->entityTypeManager = $entityTypeManager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $pluginId, $pluginDefinition) {
    return new static(
      $configuration,
      $pluginId,
      $pluginDefinition,
      $container->get('entity_type.manager')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    return [

      'richtext_component_fields' => [
        'text_format' => [],
      ],
    ] + parent::defaultConfiguration();
  }

  /**
   * {@inheritdoc}
   */
  public function blockForm($form, FormStateInterface $formState) {

    $form['text_format'] = [
      '#type' => 'text_format',
      '#title' => $this->t('Rich text'),
      '#default_value' => $this->configuration['richtext_component_fields']['text_format']['value'],
      '#format' => $this->configuration['text_format']['format'],
      '#weight' => '3',
    ];

    $form['#attached']['library'] = ['layout_builder_kit/rich-text-styling'];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function blockSubmit($form, FormStateInterface $formState) {
    $this->configuration['richtext_component_fields']['text_format'] = $formState->getValue('text_format');
  }

  /**
   * {@inheritdoc}
   */
  public function build() {
    $build = [];
    // Add template.
    $build['#theme'] = 'LBKRichText';
    // Attach library.
    $build['#attached']['library'] = ['layout_builder_kit/rich-text-styling'];

    $build['#title'] = $this->configuration['title'];
    $build['#display_title'] = $this->configuration['display_title'];
    $build['#rich_text']['#markup'] = $this->configuration['richtext_component_fields']['text_format']['value'];
    $build['#classes'] = $this->configuration['classes'];

    return $build;
  }

}
